@@ -1,5 +1,9 @@
 import inspect
 from pathlib import Path
+import pytest
+
+pytest.register_assert_rewrite("byu_pytest_utils.io_checker")
+
 
 from .test_utils import compare_files, run_python, with_import
 from .decorators import max_score, visibility, tags
